@@ -96,6 +96,10 @@ The logger subroutine set in the constructor.
 
 Remove auxiliary files (like the complete file and the status file)
 
+=item luatex
+
+Use luatex instead of xetex
+
 =back
 
 =cut
@@ -110,6 +114,10 @@ sub new {
     bless $self, $class;
 }
 
+sub luatex {
+    return shift->{luatex};
+}
+
 sub name {
     return shift->{name};
 }
@@ -444,7 +452,9 @@ sub pdf {
     foreach my $i (1..3) {
         my $pipe = IO::Pipe->new;
         # parent swallows the output
-        $pipe->reader(xelatex => '-interaction=nonstopmode', $source);
+        my $latexname = $self->luatex ? 'LuaLaTeX' : 'XeLaTeX';
+        my $latex = $self->luatex ? 'lualatex' : 'xelatex';
+        $pipe->reader($latex, '-interaction=nonstopmode', $source);
         $pipe->autoflush(1);
         my $shitout;
         while (<$pipe>) {
@@ -459,7 +469,7 @@ sub pdf {
         wait;
         my $exit_code = $? >> 8;
         if ($exit_code != 0) {
-            $self->log_info("XeLaTeX compilation failed with exit code $exit_code\n");
+            $self->log_info("$latexname compilation failed with exit code $exit_code\n");
             if (-f $self->name  . '.log') {
                 # if we have a .pdf file, this means something was
                 # produced. Hence, remove the .pdf
@@ -773,15 +783,21 @@ sub parse_tex_log_file {
         # in half, producing invalid utf8 octects.
         open (my $fh, '<:raw', $logfile)
           or $self->log_fatal("Couldn't open $logfile $!");
+
+        my %errors;
+
         while (my $line = <$fh>) {
             if ($line =~ m/^missing character/i) {
                 chomp $line;
                 # if we get the warning, nothing we can do about it,
                 # but shouldn't happen.
-                $self->log_info(decode_utf8($line) . "...\n");
+                $errors{$line} = 1;
             }
         }
         close $fh;
+        foreach my $error (sort keys %errors) {
+            $self->log_info(decode_utf8($error) . "...\n");
+        }
     }
 }
 
